@@ -29,7 +29,6 @@
 #endif
 
 #include <glib-object.h>
-#include <gdk/gdk.h>
 
 G_BEGIN_DECLS
 
@@ -40,20 +39,18 @@ G_BEGIN_DECLS
 #define GNOME_IS_IDLE_MONITOR_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), GNOME_TYPE_IDLE_MONITOR))
 #define GNOME_IDLE_MONITOR_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GNOME_TYPE_IDLE_MONITOR, GnomeIdleMonitorClass))
 
-typedef struct _GnomeIdleMonitor GnomeIdleMonitor;
-typedef struct _GnomeIdleMonitorClass GnomeIdleMonitorClass;
-typedef struct _GnomeIdleMonitorPrivate GnomeIdleMonitorPrivate;
+typedef struct GnomeIdleMonitorPrivate GnomeIdleMonitorPrivate;
 
-struct _GnomeIdleMonitor
+typedef struct
 {
         GObject                  parent;
         GnomeIdleMonitorPrivate *priv;
-};
+} GnomeIdleMonitor;
 
-struct _GnomeIdleMonitorClass
+typedef struct
 {
         GObjectClass          parent_class;
-};
+} GnomeIdleMonitorClass;
 
 typedef void (*GnomeIdleMonitorWatchFunc) (GnomeIdleMonitor      *monitor,
                                            guint                  id,
@@ -62,18 +59,13 @@ typedef void (*GnomeIdleMonitorWatchFunc) (GnomeIdleMonitor      *monitor,
 GType              gnome_idle_monitor_get_type     (void);
 
 GnomeIdleMonitor * gnome_idle_monitor_new          (void);
-GnomeIdleMonitor * gnome_idle_monitor_new_for_device (GdkDevice *device);
 
-guint              gnome_idle_monitor_add_idle_watch    (GnomeIdleMonitor         *monitor,
-							 guint64                   interval_msec,
-							 GnomeIdleMonitorWatchFunc callback,
-							 gpointer                  user_data,
-							 GDestroyNotify            notify);
-
-guint              gnome_idle_monitor_add_user_active_watch (GnomeIdleMonitor          *monitor,
-							     GnomeIdleMonitorWatchFunc  callback,
-							     gpointer		     user_data,
-							     GDestroyNotify	     notify);
+void               gnome_idle_monitor_add_watch    (GnomeIdleMonitor         *monitor,
+                                                    guint                     interval,
+                                                    GnomeIdleMonitorWatchFunc callback,
+                                                    gpointer                  user_data,
+                                                    GDestroyNotify            notify,
+	                                            guint                    *watch_id);
 
 void               gnome_idle_monitor_remove_watch (GnomeIdleMonitor         *monitor,
                                                     guint                     id);
